@@ -476,6 +476,7 @@ skip_impl = (
     'virNetworkGetDHCPLeases',
     'virDomainBlockCopy',
     'virNodeAllocPages',
+    'virDomainGetFSInfo',
 )
 
 lxc_skip_impl = (
@@ -586,6 +587,7 @@ skip_function = (
 
     'virNetworkDHCPLeaseFree', # only useful in C, python code uses list
     'virDomainStatsRecordListFree', # only useful in C, python uses dict
+    'virDomainFSInfoFree', # only useful in C, python code uses list
 )
 
 lxc_skip_function = (
@@ -819,6 +821,27 @@ def print_function_wrapper(module, name, output, export, include):
             return 0
     return 1
 
+def print_c_pointer(classname, output, export, include):
+    output.write("PyObject *\n")
+    output.write("libvirt_%s_pointer(PyObject *self ATTRIBUTE_UNUSED, PyObject *args)\n" % classname)
+    output.write("{\n")
+    output.write("    %sPtr ptr;\n" % classname)
+    output.write("    PyObject *pyptr;\n")
+    output.write("    PyObject *pylong;\n")
+    output.write("\n")
+    output.write("    if (!PyArg_ParseTuple(args, (char *) \"O\", &pyptr))\n")
+    output.write("        return NULL;\n")
+    output.write("    ptr = (%sPtr) Py%s_Get(pyptr);\n" % (classname, classname))
+    output.write("    pylong = PyLong_FromVoidPtr(ptr);\n")
+    output.write("    return pylong;\n")
+    output.write("}\n")
+    output.write("\n")
+
+    include.write("PyObject *libvirt_%s_pointer(PyObject *self, PyObject *args);\n" % classname)
+
+    export.write("    { (char *)\"%s_pointer\", libvirt_%s_pointer, METH_VARARGS, NULL },\n" %
+                 (classname, classname))
+
 def buildStubs(module, api_xml):
     global py_types
     global py_return_types
@@ -915,6 +938,12 @@ def buildStubs(module, api_xml):
             del funcs[function]
         if ret == 1:
             nb_wrap = nb_wrap + 1
+
+    if module == "libvirt":
+        # Write C pointer conversion functions.
+        for classname in primary_classes:
+            print_c_pointer(classname, wrapper, export, include)
+
     include.close()
     export.close()
     wrapper.close()
@@ -1107,6 +1136,9 @@ def nameFixup(name, classe, type, file):
     elif name[0:20] == "virDomainGetCPUStats":
         func = name[9:]
         func = func[0:1].lower() + func[1:]
+    elif name[0:18] == "virDomainGetFSInfo":
+        func = name[12:]
+        func = func[0:2].lower() + func[2:]
     elif name[0:12] == "virDomainGet":
         func = name[12:]
         func = func[0:1].lower() + func[1:]
@@ -1491,6 +1523,11 @@ def buildWrappers(module):
                 classes.write("    def domain(self):\n")
                 classes.write("        return self._dom\n\n")
 
+            classes.write("    def c_pointer(self):\n")
+            classes.write("        \"\"\"Get C pointer to underlying object\"\"\"\n")
+            classes.write("        return libvirtmod.%s_pointer(self._o)\n\n" %
+                          classname)
+
             flist = function_classes[classname]
             flist.sort(key=functionSortKey)
             oldfile = ""
